==> nxui-0.15.6.crate: nxui-0.15.6/src/widget/checkbox.rs <==
use crate::messagebox::MessageBox;
use crate::natives_and_messaging::*;
use crate::window::{Attributes, Frame};

pub struct CheckBox {
    pub handle: windows_sys::Win32::Foundation::HWND
}

impl CheckBox {
    pub fn new(attributes: Attributes,frame: Frame) -> Self {
        use windows_sys::Win32::UI::WindowsAndMessaging::*;
        unsafe {
            let handle = CreateWindowExA(0, "BUTTON\0".as_ptr(), format!("{}\0",attributes.title).as_ptr(), WS_CHILD|BS_AUTOCHECKBOX as u32, attributes.x, attributes.y, attributes.width, attributes.height, frame.get_window(), 0, 0, std::ptr::null_mut());
            if handle == 0 {
                match MessageBox::new("NXUI Warning", "NXUI Warning - Code 0002\rWidget could not be initialized\rRunning it as is may disrupt the UI\rPress Yes to continue program execution\r \rDetailed information:\rPanicked at nxui::widget::checkbox\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_WARNING, BS_YESNO).show(Frame::default())
                {
                    DR_NO => {
                        panic!("Exit request from user");
                    }
                    _ => {}
                };
            }
            info!("CheckBox has been created. handle: {}",handle);
            Self {
                handle
            }
        }
    }

    pub fn show(&self) {
        use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
        use windows_sys::Win32::UI::WindowsAndMessaging::SW_SHOWNORMAL;
        unsafe {
            ShowWindow(self.handle,SW_SHOWNORMAL);
            info!("handle: {}",self.handle);
        }
    }
}

==> nxui-0.15.16.crate: nxui-0.15.16/src/widget/checkbox.rs <==
use crate::messagebox::MessageBox;
use crate::natives_and_messaging::*;
use crate::window::{Attributes, Frame};

#[cfg(windows)]
pub struct CheckBox {
    pub handle: windows_sys::Win32::Foundation::HWND
}

#[cfg(windows)]
impl CheckBox {
    pub fn new(attributes: Attributes,frame: &Frame) -> Self {
        use windows_sys::Win32::UI::WindowsAndMessaging::*;
        unsafe {
            let handle = CreateWindowExA(0, "BUTTON\0".as_ptr(), format!("{}\0",attributes.title).as_ptr(), WS_CHILD|BS_AUTOCHECKBOX as u32, attributes.x, attributes.y, attributes.width, attributes.height, frame.get_window(), 0, 0, std::ptr::null_mut());
            if handle == 0 {
                match MessageBox::new("NXUI Warning", "NXUI Warning - Code 0002\rWidget could not be initialized\rRunning it as is may disrupt the UI\rPress Yes to continue program execution\r \rDetailed information:\rPanicked at nxui::widget::checkbox\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_WARNING, BS_YESNO).show(Frame::default())
                {
                    DR_NO => {
                        panic!("Exit request from user");
                    }
                    _ => {}
                };
            }
            info!("CheckBox has been created. handle: {}",handle);
            Self {
                handle
            }
        }
    }

    pub fn show(&self) {
        use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
        use windows_sys::Win32::UI::WindowsAndMessaging::SW_SHOWNORMAL;
        unsafe {
            ShowWindow(self.handle,SW_SHOWNORMAL);
            info!("handle: {}",self.handle);
        }
    }
}
